powered by
This function takes a path to a directory containing CSV files of census data tables, and a path to an output directory. It cleans the data tables and exports them as Excel files to the output directory.
prepare_census_tables(input_path, output_path, write_output = FALSE)
If write_to_file is TRUE, a list of file paths for the Excel filesw will be produced.
Path to directory containing input CSV files
Path to output directory for Excel files
Logical, indicating whether or not to write the output to file (default: FALSE)
temp_dir <- tempdir() file_path <- paste0(temp_dir, "/", "outputs/") prepare_census_tables(system.file("extdata/census_data", package = "OHCSpackage"), file_path, write_output = TRUE)
Run the code above in your browser using DataLab